@@ -1,22 +1,15 @@
 import sys
 import os
 
-dir = os.getcwd()
-#print(dir)
-#paths=dir.split("\")
-
-sys.path.append(dir + "\SmartApi")
-#print(sys.path)
-
 from smartConnect import SmartConnect
 
-smartApi =SmartConnect(api_key="smartapi_key")
+smartApi =SmartConnect(api_key="Your Api Key")
 
-login = smartApi.generateSession('Your client id', 'Password')
+login = smartApi.generateSession('Your Client Id', 'Your Password')
 print(login)
 refreshToken = login['data']['refreshToken']
 smartApi.getProfile(refreshToken)
-#smartApi.generateToken(refreshToken)
+smartApi.generateToken(refreshToken)
 orderparams = {
     "variety": "NORMAL",
     "tradingsymbol": "SBIN-EQ",
@@ -70,11 +63,11 @@ params={
 }
 
 smartApi.convertPosition(params)
-smartApi.terminateSession('Your client code')
+smartApi.terminateSession("Your Client Id")
 
 from smartapi.smartSocket import SmartSocket
-FEED_TOKEN='feedToken' #'1731759952'
-CLIENT_CODE='Your client id' #'S212741'
+FEED_TOKEN="Your Feed Token"
+CLIENT_CODE="Your Client Id"
 token=None
 ss = SmartSocket(FEED_TOKEN, CLIENT_CODE)
 def on_tick(ws, tick):
